=======
History
=======
1.0.1 (2021-10-21) Fixes a bug that did not allow parameter dictionary I/O in HyperModelCores

1.0.0 (2021-10-18) Capabilities to save as HDF5 files. Added full documentation and filled out the testing suite.

0.4.0 (2021-09-24) Added CI testing suite and cleaned up functions.

0.3.0 (2020-10-28) New docs.

0.2.0 (2020-02-13) Cleaned up various functionality and added more docs.

0.1.0 (2018-09-21)*
-------------------

* First release on PyPI.
